==> diffusion-3.0.6.tar.gz: diffusion-3.0.6/apps/agents/agent1.cc <==
//
// agent1.cc      : Test agent #1 Main File
// author         : Fabio Silva
//
// Copyright (C) 2000-2001 by the Unversity of Southern California
// $Id: agent1.cc,v 1.8 2001/11/21 19:51:23 fabio Exp $
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License,
// version 2, as published by the Free Software Foundation.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License along
// with this program; if not, write to the Free Software Foundation, Inc.,
// 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
//
//

#include "agent.hh"

MyReceive *mr;
int last_seq_recv;
int num_msg_recv;

NRSimpleAttributeFactory<char *> TargetAttr(NRAttribute::TARGET_KEY, NRAttribute::STRING_TYPE);
NRSimpleAttributeFactory<int> AppDummyAttr(APP_KEY1, NRAttribute::INT32_TYPE);
NRSimpleAttributeFactory<int> AppCounterAttr(APP_KEY3, NRAttribute::INT32_TYPE);

void MyReceive::recv(NRAttrVec *data, NR::handle my_handle)
{
  NRSimpleAttribute<int> *counterAttr = NULL;

  counterAttr = AppCounterAttr.find(data);

  if (!counterAttr){
    diffPrint(DEBUG_ALWAYS, "Received a BAD packet !\n");
    printAttrs(data);
    return;
  }

  if (last_seq_recv >= 0){
    if (counterAttr->getVal() < last_seq_recv){
      last_seq_recv = -1;
      diffPrint(DEBUG_ALWAYS, "Received data %d !\n", counterAttr->getVal());
      // Multiple sources detected, disabling statistics
    }
    else{
      last_seq_recv = counterAttr->getVal();
      num_msg_recv++;
      diffPrint(DEBUG_ALWAYS, "Received data: %d, %% msgs received: %f !\n",
		last_seq_recv,
		(float) ((num_msg_recv * 100.00) / (last_seq_recv + 1)));
    }
  }
  else{
    diffPrint(DEBUG_ALWAYS, "Received data %d !\n", counterAttr->getVal());
  }
}

handle setupInterest(NR *dr)
{
  NRAttrVec attrs;

  attrs.push_back(NRClassAttr.make(NRAttribute::IS, NRAttribute::INTEREST_CLASS));
  attrs.push_back(LatitudeAttr.make(NRAttribute::GT, 54.78));
  attrs.push_back(LongitudeAttr.make(NRAttribute::LE, 87.32));
  attrs.push_back(TargetAttr.make(NRAttribute::IS, "F117A"));
  attrs.push_back(AppDummyAttr.make(NRAttribute::IS, 2001));

  handle h = dr->subscribe(&attrs, mr);

  ClearAttrs(&attrs);

  return h;
}

void usage()
{
  diffPrint(DEBUG_ALWAYS, "Usage: agent [-p port] [-h]\n\n");
  diffPrint(DEBUG_ALWAYS, "\t-p - Uses port 'port' to talk to diffusion\n");
  diffPrint(DEBUG_ALWAYS, "\t-h - Prints this information\n");
  diffPrint(DEBUG_ALWAYS, "\n");
  exit(0);
}

int main(int argc, char **argv)
{
  NR *dr;
  handle subHandle;
  int opt;
  u_int16_t diffusion_port = DEFAULT_DIFFUSION_PORT;

  application_id = strdup(argv[0]);

#ifdef BBN_LOGGER
  InitMainLogger();
#endif

  // Parse command line options
  opterr = 0;

  while (1){
    opt = getopt(argc, argv, "hp:");
    switch (opt){

    case 'p':

      diffusion_port = (u_int16_t) atoi(optarg);
      if ((diffusion_port < 1024) || (diffusion_port >= 65535)){
	diffPrint(DEBUG_ALWAYS, "Error: Diffusion port must be between 1024 and 65535 !\n");
	exit(-1);
      }

      break;

    case 'h':

      usage();

      break;

    case '?':

      diffPrint(DEBUG_ALWAYS, "Error: %c isn't a valid option or its parameter is missing !\n", optopt);
      usage();

      break;

    case ':':

      diffPrint(DEBUG_ALWAYS, "Parameter missing !\n");
      usage();

      break;

    }

    if (opt == -1)
      break;
  }

  dr = NR::createNR(diffusion_port);
  mr = new MyReceive;

  subHandle = setupInterest(dr);

  last_seq_recv = 0;
  num_msg_recv = 0;

  while (1){
    char input;

    printf("Now what ? ");
    input = getc(stdin);

    if (input == 'c'){
      dr->unsubscribe(subHandle);
      exit(0);
    }
  }

  return 0;
}

==> diffusion-3.0.7.tar.gz: diffusion-3.0.7/apps/agents/agent1.cc <==
//
// agent1.cc      : Test agent #1 Main File
// author         : Fabio Silva
//
// Copyright (C) 2000-2001 by the Unversity of Southern California
// $Id: agent1.cc,v 1.10 2002/02/22 01:17:42 fabio Exp $
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License,
// version 2, as published by the Free Software Foundation.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License along
// with this program; if not, write to the Free Software Foundation, Inc.,
// 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
//
//

#include "agent.hh"

MyReceive *mr;
int last_seq_recv;
int num_msg_recv;

NRSimpleAttributeFactory<char *> TargetAttr(NRAttribute::TARGET_KEY, NRAttribute::STRING_TYPE);
NRSimpleAttributeFactory<int> AppDummyAttr(APP_KEY1, NRAttribute::INT32_TYPE);
NRSimpleAttributeFactory<int> AppCounterAttr(APP_KEY3, NRAttribute::INT32_TYPE);

void MyReceive::recv(NRAttrVec *data, NR::handle my_handle)
{
  NRSimpleAttribute<int> *counterAttr = NULL;

  counterAttr = AppCounterAttr.find(data);

  if (!counterAttr){
    diffPrint(DEBUG_ALWAYS, "Received a BAD packet !\n");
    PrintAttrs(data);
    return;
  }

  if (last_seq_recv >= 0){
    if (counterAttr->getVal() < last_seq_recv){
      last_seq_recv = -1;
      diffPrint(DEBUG_ALWAYS, "Received data %d !\n", counterAttr->getVal());
      // Multiple sources detected, disabling statistics
    }
    else{
      last_seq_recv = counterAttr->getVal();
      num_msg_recv++;
      diffPrint(DEBUG_ALWAYS, "Received data: %d, %% msgs received: %f !\n",
		last_seq_recv,
		(float) ((num_msg_recv * 100.00) / (last_seq_recv + 1)));
    }
  }
  else{
    diffPrint(DEBUG_ALWAYS, "Received data %d !\n", counterAttr->getVal());
  }
}

handle setupInterest(NR *dr)
{
  NRAttrVec attrs;

  attrs.push_back(NRClassAttr.make(NRAttribute::IS, NRAttribute::INTEREST_CLASS));
  attrs.push_back(LatitudeAttr.make(NRAttribute::GT, 54.78));
  attrs.push_back(LongitudeAttr.make(NRAttribute::LE, 87.32));
  attrs.push_back(TargetAttr.make(NRAttribute::IS, "F117A"));
  attrs.push_back(AppDummyAttr.make(NRAttribute::IS, 2001));

  handle h = dr->subscribe(&attrs, mr);

  ClearAttrs(&attrs);

  return h;
}

void usage()
{
  diffPrint(DEBUG_ALWAYS, "Usage: agent [-p port] [-h]\n\n");
  diffPrint(DEBUG_ALWAYS, "\t-p - Uses port 'port' to talk to diffusion\n");
  diffPrint(DEBUG_ALWAYS, "\t-h - Prints this information\n");
  diffPrint(DEBUG_ALWAYS, "\n");
  exit(0);
}

int main(int argc, char **argv)
{
  NR *dr;
  handle subHandle;
  int opt;
  u_int16_t diffusion_port = DEFAULT_DIFFUSION_PORT;
  fd_set FDS;

  application_id = strdup(argv[0]);

#ifdef BBN_LOGGER
  InitMainLogger();
#endif

  // Parse command line options
  opterr = 0;

  while (1){
    opt = getopt(argc, argv, "hp:");
    switch (opt){

    case 'p':

      diffusion_port = (u_int16_t) atoi(optarg);
      if ((diffusion_port < 1024) || (diffusion_port >= 65535)){
	diffPrint(DEBUG_ALWAYS, "Error: Diffusion port must be between 1024 and 65535 !\n");
	exit(-1);
      }

      break;

    case 'h':

      usage();

      break;

    case '?':

      diffPrint(DEBUG_ALWAYS, "Error: %c isn't a valid option or its parameter is missing !\n", optopt);
      usage();

      break;

    case ':':

      diffPrint(DEBUG_ALWAYS, "Parameter missing !\n");
      usage();

      break;

    }

    if (opt == -1)
      break;
  }

  dr = NR::createNR(diffusion_port);
  mr = new MyReceive;

  subHandle = setupInterest(dr);

  last_seq_recv = 0;
  num_msg_recv = 0;

  while (1){
    FD_SET(0, &FDS);

    char input;

    fprintf(stdout, "Now what ? ");
    fflush(NULL);
    select(1, &FDS, NULL, NULL, NULL);
    input = getc(stdin);

    if (input == 'c'){
      dr->unsubscribe(subHandle);
      exit(0);
    }
  }

  return 0;
}
